==> haskell-data-default-instances-containers-0.0.1-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-default-instances-containers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-default-instances-containers
version: 0.0.1
id: data-default-instances-containers-0.0.1-EuylP0qAiv52WAOyUJkumA
key: data-default-instances-containers-0.0.1-EuylP0qAiv52WAOyUJkumA
license: BSD-3-Clause
maintainer: <l.mai@web.de>
author: Lukas Mai
synopsis: Default instances for types in containers
category: Data
abi: 0c28972686b0eea5a6efd88d69f8479d
exposed: True
exposed-modules:
    Data.Default.Instances.Containers
import-dirs: /usr/lib/ghc-8.4.3/site-local/data-default-instances-containers-0.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/data-default-instances-containers-0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/data-default-instances-containers-0.0.1
hs-libraries: HSdata-default-instances-containers-0.0.1-EuylP0qAiv52WAOyUJkumA
depends:
    base-4.11.1.0 containers-0.5.11.0
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
haddock-interfaces: /usr/share/doc/haskell-data-default-instances-containers/html/data-default-instances-containers.haddock
haddock-html: /usr/share/doc/haskell-data-default-instances-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-containers-0.0.1-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-default-instances-containers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-default-instances-containers
version: 0.0.1
id: data-default-instances-containers-0.0.1-2FwsTo28ZcmGL0uNHIMmBu
key: data-default-instances-containers-0.0.1-2FwsTo28ZcmGL0uNHIMmBu
license: BSD-3-Clause
maintainer: <l.mai@web.de>
author: Lukas Mai
synopsis: Default instances for types in containers
category: Data
abi: 9d21515e334f6d56513c3ee016d7989f
exposed: True
exposed-modules:
    Data.Default.Instances.Containers
import-dirs: /usr/lib/ghc-8.6.1/site-local/data-default-instances-containers-0.0.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/data-default-instances-containers-0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/data-default-instances-containers-0.0.1
hs-libraries: HSdata-default-instances-containers-0.0.1-2FwsTo28ZcmGL0uNHIMmBu
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
haddock-interfaces: /usr/share/doc/haskell-data-default-instances-containers/html/data-default-instances-containers.haddock
haddock-html: /usr/share/doc/haskell-data-default-instances-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
